@@ -1,13 +1,14 @@
 package Chloro::Error::Field;
-BEGIN {
-  $Chloro::Error::Field::VERSION = '0.06';
-}
+
+use strict;
+use warnings;
+use namespace::autoclean;
+
+our $VERSION = '0.07';
 
 use Moose;
 use MooseX::StrictConstructor;
 
-use namespace::autoclean;
-
 use Chloro::Field;
 
 with 'Chloro::Role::Error';
@@ -37,26 +38,28 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: An error associated with a specific field
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Chloro::Error::Field - An error associated with a specific field
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
     my $errors = $resultset->result_for('field')->errors();
 
-    for my $message ( @{$errors} ) {
-        print $message->field()->name();
+    for my $error ( @{$errors} ) {
+        print $error->field()->name();
         print ': ';
-        print $message->error()->text();
+        print $error->message()->text();
     }
 
 =head1 DESCRIPTION
@@ -84,20 +87,29 @@ Returns a L<Chloro::ErrorMessage> object.
 
 This object does the L<Chloro::Role::Error> role.
 
+=head1 SUPPORT
+
+Bugs may be submitted at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Chloro> or via email to L<bug-chloro@rt.cpan.org|mailto:bug-chloro@rt.cpan.org>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Chloro can be found at L<https://github.com/autarch/Chloro>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
-
-
-__END__
-
