@@ -1,13 +1,14 @@
 package Chloro::Field;
-BEGIN {
-  $Chloro::Field::VERSION = '0.06';
-}
+
+use strict;
+use warnings;
+use namespace::autoclean;
+
+our $VERSION = '0.07';
 
 use Moose;
 use MooseX::StrictConstructor;
 
-use namespace::autoclean;
-
 use Chloro::Types qw( Bool CodeRef NonEmptySimpleStr Str Value );
 use Moose::Util::TypeConstraints;
 
@@ -101,12 +102,14 @@ sub STORABLE_thaw {
     %{$self} = %{$obj};
 
     $self->{type}
-        = Moose::Util::TypeConstraints::find_or_create_type_constraint( ${$type} );
+        = Moose::Util::TypeConstraints::find_or_create_type_constraint(
+        ${$type} );
 
     return;
 }
 
 # This exists mostly to make testing easier
+## no critic (Subroutines::ProhibitBuiltinHomonyms)
 sub dump {
     my $self = shift;
 
@@ -117,6 +120,7 @@ sub dump {
         ( $self->has_default() ? ( default => $self->default() ) : () ),
     );
 }
+## use critic
 
 __PACKAGE__->meta()->make_immutable();
 
@@ -124,17 +128,19 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: A field in a form
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Chloro::Field - A field in a form
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -144,6 +150,8 @@ See L<Chloro>.
 
 This class represents a field in a form.
 
+=for Pod::Coverage STORABLE_freeze STORABLE_thaw
+
 =head1 METHODS
 
 This class has the following methods:
@@ -266,20 +274,29 @@ primarily for testing.
 
 This class consumes the L<Chloro::Role::FormComponent> role.
 
+=head1 SUPPORT
+
+Bugs may be submitted at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Chloro> or via email to L<bug-chloro@rt.cpan.org|mailto:bug-chloro@rt.cpan.org>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Chloro can be found at L<https://github.com/autarch/Chloro>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
-
-
-__END__
-
