@@ -1,13 +1,14 @@
 package Chloro::Group;
-BEGIN {
-  $Chloro::Group::VERSION = '0.06';
-}
+
+use strict;
+use warnings;
+use namespace::autoclean;
+
+our $VERSION = '0.07';
 
 use Moose;
 use MooseX::StrictConstructor;
 
-use namespace::autoclean;
-
 use Chloro::Types qw( CodeRef HashOfFields NonEmptyStr NonEmptySimpleStr );
 
 with 'Chloro::Role::FormComponent';
@@ -36,6 +37,7 @@ has is_empty_checker => (
     default => '_group_is_empty',
 );
 
+## no critic (Subroutines::ProhibitBuiltinHomonyms)
 sub dump {
     my $self = shift;
 
@@ -44,6 +46,7 @@ sub dump {
         fields => { map { $_->name() => { $_->dump() } } $self->fields() },
     );
 }
+## use critic
 
 __PACKAGE__->meta()->make_immutable();
 
@@ -51,17 +54,19 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: A field in a form
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Chloro::Group - A field in a form
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -144,20 +149,29 @@ primarily for testing.
 
 This class consumes the L<Chloro::Role::FormComponent> role.
 
+=head1 SUPPORT
+
+Bugs may be submitted at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Chloro> or via email to L<bug-chloro@rt.cpan.org|mailto:bug-chloro@rt.cpan.org>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Chloro can be found at L<https://github.com/autarch/Chloro>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
-
-
-__END__
-
