@@ -1,13 +1,14 @@
 package Chloro::Result::Group;
-BEGIN {
-  $Chloro::Result::Group::VERSION = '0.06';
-}
+
+use strict;
+use warnings;
+use namespace::autoclean;
+
+our $VERSION = '0.07';
 
 use Moose;
 use MooseX::StrictConstructor;
 
-use namespace::autoclean;
-
 use Chloro::Error::Field;
 use Chloro::Types qw( Bool NonEmptyStr );
 use List::AllUtils qw( any );
@@ -43,7 +44,7 @@ has is_valid => (
 sub _build_is_valid {
     my $self = shift;
 
-    return 0 if any { ! $_->is_valid() } $self->_result_values();
+    return 0 if any { !$_->is_valid() } $self->_result_values();
 
     return 1;
 }
@@ -63,17 +64,19 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: A result for a single group
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Chloro::Result::Group - A result for a single group
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -157,20 +160,29 @@ Returns the result as a key/value pair, where the keys are field names
 This class does the L<Chloro::Role::Result> and L<Chloro::Role::ResultSet>
 role.
 
+=head1 SUPPORT
+
+Bugs may be submitted at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Chloro> or via email to L<bug-chloro@rt.cpan.org|mailto:bug-chloro@rt.cpan.org>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Chloro can be found at L<https://github.com/autarch/Chloro>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
-
-
-__END__
-
