@@ -1,13 +1,14 @@
 package Chloro::ResultSet;
-BEGIN {
-  $Chloro::ResultSet::VERSION = '0.06';
-}
+
+use strict;
+use warnings;
+use namespace::autoclean;
+
+our $VERSION = '0.07';
 
 use Moose;
 use MooseX::StrictConstructor;
 
-use namespace::autoclean;
-
 use Chloro::Error::Form;
 use Chloro::Types qw( ArrayRef Bool HashRef );
 use List::AllUtils qw( any );
@@ -46,7 +47,7 @@ sub _build_is_valid {
 
     return 0 if $self->_has_form_errors();
 
-    return 0 if any { ! $_->is_valid() } $self->_result_values();
+    return 0 if any { !$_->is_valid() } $self->_result_values();
 
     return 1;
 }
@@ -158,17 +159,19 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: The set of results from processing a form submission
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Chloro::ResultSet - The set of results from processing a form submission
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -280,20 +283,29 @@ are returned a list.
 This class does the L<Chloro::Role::Result> and L<Chloro::Role::ResultSet>
 role.
 
+=head1 SUPPORT
+
+Bugs may be submitted at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Chloro> or via email to L<bug-chloro@rt.cpan.org|mailto:bug-chloro@rt.cpan.org>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Chloro can be found at L<https://github.com/autarch/Chloro>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
-
-
-__END__
-
