@@ -1,12 +1,13 @@
 package Chloro::Role::Form;
-BEGIN {
-  $Chloro::Role::Form::VERSION = '0.06';
-}
+
+use strict;
+use warnings;
+use namespace::autoclean;
+
+our $VERSION = '0.07';
 
 use Moose::Role;
 
-use namespace::autoclean;
-
 use Chloro::Error::Form;
 use Chloro::ErrorMessage;
 use Chloro::Result::Field;
@@ -100,7 +101,7 @@ sub _result_for_field {
         errors      => [
             map {
                 Chloro::Error::Field->new( field => $field, message => $_ )
-                } @{$errors}
+            } @{$errors}
         ],
         ( defined $value ? ( value => $value ) : () ),
     );
@@ -124,7 +125,7 @@ sub _validate_field {
         if ( $field->type()->is_a_type_of('Bool') ) {
             $value = 0;
         }
-        elsif ( ! $field->is_required() ) {
+        elsif ( !$field->is_required() ) {
             return;
         }
     }
@@ -147,7 +148,7 @@ sub _validate_field {
             # it's not at all end user friendly.
             push @errors,
                 Chloro::ErrorMessage->new(
-                text => 'The '
+                      text => 'The '
                     . $field->human_name()
                     . ' field did not contain a valid value.',
                 category => 'invalid',
@@ -168,6 +169,7 @@ sub _validate_field {
     return ( $value, \@names, \@errors );
 }
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _extract_field_value {
     my $self   = shift;
     my $params = shift;
@@ -180,6 +182,7 @@ sub _extract_field_value {
 }
 
 sub _errors_for_field_value {
+
     # my $self   = shift;
     # my $value  = shift;
     # my $params = shift;
@@ -188,6 +191,7 @@ sub _errors_for_field_value {
 
     return;
 }
+## use critic
 
 sub _results_for_group {
     my $self   = shift;
@@ -196,10 +200,8 @@ sub _results_for_group {
 
     my $keys = $params->{ $group->repetition_key() };
 
-    return
-        map { $self->_result_for_group_by_key( $group, $params, $_ ) }
-        grep { defined && length }
-        ref $keys ? @{$keys} : $keys;
+    return map { $self->_result_for_group_by_key( $group, $params, $_ ) }
+        grep { defined && length } ref $keys ? @{$keys} : $keys;
 }
 
 sub _result_for_group_by_key {
@@ -227,6 +229,7 @@ sub _result_for_group_by_key {
     );
 }
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _group_is_empty {
     my $self   = shift;
     my $params = shift;
@@ -236,6 +239,7 @@ sub _group_is_empty {
     return all { !( defined $params->{$_} && length $params->{$_} ) }
     map { join q{.}, $prefix, $_->name() } $group->fields();
 }
+## use critic
 
 sub _validate_form { }
 
@@ -247,17 +251,19 @@ sub _value_is_empty {
 
 # ABSTRACT: A role for form classes
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Chloro::Role::Form - A role for form classes
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -321,20 +327,29 @@ By default, this is a no-op method, but you can provide your own
 implementation to do whole form validation. See L<Chloro::Manual::Intro> for
 an example.
 
+=head1 SUPPORT
+
+Bugs may be submitted at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Chloro> or via email to L<bug-chloro@rt.cpan.org|mailto:bug-chloro@rt.cpan.org>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Chloro can be found at L<https://github.com/autarch/Chloro>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
-
-
-__END__
-
