@@ -1,12 +1,14 @@
 package Chloro::Types;
-BEGIN {
-  $Chloro::Types::VERSION = '0.06';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.07';
+
+use MooseX::Types::Common::String ();
+use MooseX::Types::Moose          ();
+
 use base 'MooseX::Types::Combine';
 
 __PACKAGE__->provide_types_from(
@@ -16,3 +18,5 @@ __PACKAGE__->provide_types_from(
         Chloro::Types::Internal
         )
 );
+
+1;
