@@ -1,10 +1,10 @@
 package Chloro::Types::Internal;
-BEGIN {
-  $Chloro::Types::Internal::VERSION = '0.06';
-}
 
 use strict;
 use warnings;
+use namespace::autoclean;
+
+our $VERSION = '0.07';
 
 use MooseX::Types -declare => [
     qw(
