@@ -1,6 +1,8 @@
 package Chloro::Test::DateFromStr;
 
 use Moose;
+use namespace::autoclean;
+
 use Chloro;
 
 use Chloro::Types qw( Str );
@@ -13,11 +15,11 @@ field date => (
     extractor => '_extract_date',
 );
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _extract_date {
     my $self   = shift;
     my $params = shift;
     my $prefix = shift;
-    my $field  = shift;
 
     my %keys = map { $_ => $_ } qw( year month day );
 
@@ -32,7 +34,7 @@ sub _extract_date {
         ( 'year', 'month', 'day' ),
     );
 }
-
+## use critic
 
 __PACKAGE__->meta()->make_immutable;
 
