@@ -1,6 +1,8 @@
 package Chloro::Test::Default;
 
 use Moose;
+use namespace::autoclean;
+
 use Chloro;
 
 use Chloro::Types qw( ArrayRef Int );
@@ -28,7 +30,7 @@ group baz => (
             isa     => ArrayRef,
             default => sub { [ $_[1], $_[2] ] },
         )
-    )
+    ),
 );
 
 __PACKAGE__->meta()->make_immutable;
