@@ -1,6 +1,8 @@
 package Chloro::Test::NoNameExtractor;
 
 use Moose;
+use namespace::autoclean;
+
 use Chloro;
 
 use Chloro::Types qw( Str );
@@ -11,14 +13,14 @@ field foo => (
     extractor => '_extract_foo',
 );
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _extract_foo {
     my $self   = shift;
     my $params = shift;
-    my $prefix = shift;
-    my $field  = shift;
 
     return $params->{foo};
 }
+## use critic
 
 __PACKAGE__->meta()->make_immutable;
 
