@@ -1,6 +1,8 @@
 package Chloro::Test::Validator;
 
 use Moose;
+use namespace::autoclean;
+
 use Chloro;
 
 use Chloro::Types qw( Int );
@@ -16,16 +18,17 @@ field max => (
     validator => '_max_greater_than_min',
 );
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _max_greater_than_min {
     my $self   = shift;
     my $value  = shift;
     my $params = shift;
-    my $field  = shift;
 
     return if $value > $params->{min};
 
     return 'The max value must be greater than the min value.';
 }
+## use critic
 
 __PACKAGE__->meta()->make_immutable;
 
